@@ -1,11 +1,11 @@
 ### -*- coding: utf-8 -*- #############################################
 """Adapter of division to attribute dir component.
 
-$Id: attributediradapter.py 13543 2007-12-10 00:52:49Z cray $
+$Id: attributediradapter.py 49222 2008-01-06 04:47:35Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 13543 $"
+__version__ = "$Revision: 49222 $"
 
 
 from ng.ftp.attributedirectory import AttributeDirBase
@@ -19,5 +19,7 @@ class AttributeDirAdapter(AttributeDirBase) :
     @property
     def ifaces(self) :
         return list(providedBy(self.context))
-    
-    
+
+    def filter(self,name) :
+        return name[0] != "_" and super(AttributeDirAdapter,self).filter(name)
+                
