@@ -1,15 +1,16 @@
 ### -*- coding: utf-8 -*- #############################################
 """Container adapters the Zope 3 based contentobjects package
 
-$Id: writedirectory.py 13543 2007-12-10 00:52:49Z cray $
+$Id: writedirectory.py 49222 2008-01-06 04:47:35Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 13543 $"
+__version__ = "$Revision: 49222 $"
  
 from zope.interface import Interface,implements
 from zope.filerepresentation.interfaces import IWriteFile,IWriteDirectory
 from utils import packkey, unpackkey, unpacktype
+import sys
 
 class WriteDirectoryAdapter(object) :
     implements(IWriteDirectory)
@@ -19,7 +20,10 @@ class WriteDirectoryAdapter(object) :
         
     def __setitem__(self,key,value) :
         """ A KeyError is raised if there is no value for the key."""
-        self.context[unicode(unpackkey(key))] = value       
-
+        try :
+            self.context[unicode(unpackkey(key))] = value       
+        except Exception,msg :
+            print sys.excepthook(*sys.exc_info())                        
+        
     def __delitem__(self,key,value) :
         del self.context[unicode(unpackkey(key))] 
